matminer.datasets.tests package — matminer 0.6.3 documentation

# matminer.datasets.tests package

## Submodules

## matminer.datasets.tests.base module

class `matminer.datasets.tests.base.` `DatasetTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

## matminer.datasets.tests.test_convenience_loaders module

## matminer.datasets.tests.test_dataset_retrieval module

class `matminer.datasets.tests.test_dataset_retrieval.` `DataRetrievalTest`(methodName='runTest')

  Bases: `matminer.datasets.tests.base.DatasetTest`

  `test_get_all_dataset_info`()
  `test_get_dataset_attribute`()
  `test_get_dataset_citations`()
  `test_get_dataset_column_descriptions`()
  `test_get_dataset_columns`()
  `test_get_dataset_description`()
  `test_get_dataset_num_entries`()
  `test_get_dataset_reference`()
  `test_load_dataset`()
  `test_print_available_datasets`()

## matminer.datasets.tests.test_datasets module

class `matminer.datasets.tests.test_datasets.` `DataSetsTest`(methodName='runTest')

  Bases: `matminer.datasets.tests.base.DatasetTest`

  `universal_dataset_check`(dataset_name, object_headers=None, numeric_headers=None, bool_headers=None, test_func=None)

class `matminer.datasets.tests.test_datasets.` `MatminerDatasetsTest`(methodName='runTest')

  Bases: `matminer.datasets.tests.test_datasets.DataSetsTest`

  Matbench datasets are tested here.

  `test_matbench_v0_1`()

## matminer.datasets.tests.test_utils module

class `matminer.datasets.tests.test_utils.` `UtilsTest`(methodName='runTest')

  Bases: `matminer.datasets.tests.base.DatasetTest`

  `test_fetch_external_dataset`()
  `test_get_data_home`()
  `test_get_file_sha256_hash`()
  `test_load_dataset_dict`()
  `test_read_dataframe_from_file`()
  `test_validate_dataset`()

## Module contents